@@ -5,21 +5,21 @@ def get_magcluster_parser():
     
     parser = argparse.ArgumentParser(
              prog="magcluster", 
-             description='Magnetosome Gene Cluster Analysis Tool', 
+             description='Magnetosome Gene Clusters Analyzer', 
              usage='%(prog)s [options]', 
              formatter_class=argparse.RawTextHelpFormatter, 
              epilog=
             "General usage\n-------------\n"
-            "Magnetosome gene annotation:\n"
-            "  $ magcluster prokka XXX.fa\n\n"
-            "Magnetosome gene screen:\n"
-            "  $ magcluster mgc_screen XXX.gbk\n\n"
-            "Magnetosome gene cluster mapping:\n"
-            "  $ magcluster clinker XXX_screened.gbk\n\n"
+            "Genome annotation:\n"
+            "  $ magcluster prokka genome.fasta\n\n"
+            "MGCs screening:\n"
+            "  $ magcluster mgc_screen genbank.gbk\n\n"
+            "MGCs alignment and mapping:\n"
+            "  $ magcluster clinker genbank_mgc.gbk\n\n"
             
             "Runjia, 2021"
             )
-    parser.add_argument('-v', '--version', action='version', version='%(prog)s 0.1.6', help='show magcluster version number and exit')
+    parser.add_argument('-v', '--version', action='version', version='%(prog)s 0.2.0', help='show magcluster version number and exit')
     # parser.add_argument('-ascm', action='store_true', help='directly analyse from genome file to genecluster mapping.')
     #构建子命令
     subparsers = parser.add_subparsers(title='Options', dest="subparser_name")
@@ -28,17 +28,17 @@ def get_magcluster_parser():
     parser_maga.add_argument('fafile', type=str, help='Genome files need to be annotated', nargs='+')
 
     General = parser_maga.add_argument_group('General')
-    #General.add_argument('--version', help='Print version and exit', action="store_true")
-    #General.add_argument('--docs', help='Show full manual/documentation', action="store_true")
-    #General.add_argument('--citation', help='Print citation for referencing Prokka', action="store_true")
+    # General.add_argument('--version', help='Print version and exit', action="store_true")
+    # General.add_argument('--docs', help='Show full manual/documentation', action="store_true")
+    # General.add_argument('--citation', help='Print citation for referencing Prokka', action="store_true")
     General.add_argument('--quiet', help='No screen output (default OFF)', action="store_true")
     General.add_argument('--debug', help='Debug mode: keep all temporary files (default OFF)', action="store_true")
 
-    Setup = parser_maga.add_argument_group('Setup')
-    Setup.add_argument('--listdb', help='List all configured databases', action="store_true")
-    Setup.add_argument('--setupdb', help='Index all installed databases', action="store_true")
-    Setup.add_argument('--cleandb', help='Remove all database indices', action="store_true")
-    Setup.add_argument('--depends', help='List all software dependencies', action="store_true")
+    # Setup = parser_maga.add_argument_group('Setup')
+    # Setup.add_argument('--listdb', help='List all configured databases', action="store_true")
+    # Setup.add_argument('--setupdb', help='Index all installed databases', action="store_true")
+    # Setup.add_argument('--cleandb', help='Remove all database indices', action="store_true")
+    # Setup.add_argument('--depends', help='List all software dependencies', action="store_true")
 
     Outputs = parser_maga.add_argument_group('Outputs')
     Outputs.add_argument('--outdir', type=str, help="Output folder [auto] (default 'XXX_annotation')")
@@ -66,7 +66,7 @@ def get_magcluster_parser():
     Annotations.add_argument('--gcode', type=int, help="Genetic code / Translation table (set if --kingdom is set) (default '0')")
     Annotations.add_argument('--gram', type=str, help="Gram: -/neg +/pos (default '')")
     Annotations.add_argument('--usegenus', help='Use genus-specific BLAST databases (needs --genus) (default OFF)', action="store_true")
-    Annotations.add_argument('--proteins', type=str, help='Fasta file of trusted proteins to first annotate from (default '')')
+    Annotations.add_argument('--proteins', type=str, help='Fasta file of trusted proteins to first annotate from (default "Magnetosome_protein_data.fasta")')
     Annotations.add_argument('--hmms', type=str, help="Trusted HMM to first annotate from (default '')")
     Annotations.add_argument('--metagenome', help='Improve gene predictions for highly fragmented genomes (default OFF)', action="store_true")
     Annotations.add_argument('--rawproduct', help='Do not clean up /product annotation (default OFF)', action="store_true")
@@ -84,12 +84,12 @@ def get_magcluster_parser():
     Computation.add_argument('--rnammer', help="Prefer RNAmmer over Barrnap for rRNA prediction (default OFF)", action="store_true")
     
     #构建magsc子命令
-    parser_magsc = subparsers.add_parser('mgc_screen', help='Magnetosome gene cluster screening with magscreen')
-    parser_magsc.add_argument('gbkfile', type=str, help='.gbk/.gbf files to analyzed. Multiple files or files-containing folder is acceptable.', nargs='+')
-    parser_magsc.add_argument('-th','--threshold', type=int, default=2, help="The minimum number of magnetosome genes in one contig/scaffold to screen (default '2')")
+    parser_magsc = subparsers.add_parser('mgc_screen', help='Magnetosome gene cluster screening')
+    parser_magsc.add_argument('gbkfile', type=str, help='.gbk/.gbf files to be analyzed. Multiple files or files-containing folder is acceptable.', nargs='+')
+    parser_magsc.add_argument('-l', '--contiglength', type=int, default=2000, help="The minimum length of contigs to be considered (default '2,000 bp')")
+    parser_magsc.add_argument('-w', '--windowsize', type=int, default=10000, help="The length of MGCs screening window (default '10,000 bp')")
+    parser_magsc.add_argument('-th','--threshold', type=int, default=3, help="The minimum number of magnetosome genes in a given contig and a given length of screening window (default '3')")
     parser_magsc.add_argument('-o','--outdir', type=str, help="Output folder (default 'mgc_screen')")
-    parser_magsc.add_argument('-min', '--minlength', type=int, default=2000, help="Minimum length of contigs to be considered (default '2000bp')")
-    parser_magsc.add_argument('-max', '--maxlength', type=int, default=10000, help="Maximum length of contigs containing magnetosome gene (default '10000bp')")
     
     #构建magm子命令
     parser_magm = subparsers.add_parser('clinker', help='Magnetosome gene cluster mapping with Clinker')
